#change this for unittest

from pynyol.dictanum import IntParser

MAX_ALLOWED = 1e24

ip = IntParser(45)
print(ip.num)
print(ip.txt)

ip.set_number(0)
print(ip.num)
print(ip.txt)

ip.set_number(323)
print(ip.num)
print(ip.txt)

ip.set_number(401)
print(ip.num)
print(ip.txt)

ip.set_number(-567)
print(ip.num)
print(ip.txt)

ip.set_number(-567_456)
print(ip.num)
print(ip.txt)

ip.set_number(-21_236_458_236_458_123_236_458)
print(ip.num)
print(ip.txt)

ip.set_number(MAX_ALLOWED)
print(ip.num)
print(ip.txt)


from setuptools import setup

setup(
    name='pynyol',
    version='0.1.0',
    author='Juanma López',
    author_email='lopezjuanma96@gmail.com',
    packages=['pynyol', 'pynyol.test'],
    package_dir={'': './'},
    scripts=['bin/express_a_num.py'],
    url='https://pypi.org/project/pynyol',
    license='LICENSE.txt',
    description='Package aimed at helping with processing the spanish language.',
    long_description=open('README.txt').read(),
    install_requires=[
    ],
)